@@ -1,25 +1,27 @@
 """ Dictionary-to-filetree functions, to create test files for testing.
     http://nedbatchelder.com/code/cog
 
-    Copyright 2004-2015, Ned Batchelder.
+    Copyright 2004-2019, Ned Batchelder.
 """
 
 from __future__ import absolute_import
-import os.path
-from .whiteutils import reindentBlock
-from .backward import string_types, bytes_types
 
-__version__ = '1.0.20040126'
+import os.path
+
+from .backward import string_types, bytes_types
+from .whiteutils import reindentBlock
+
 __all__ = ['makeFiles', 'removeFiles']
 
-def makeFiles(d, basedir='.'):
+def makeFiles(d, basedir='.', bytes=False):
     """ Create files from the dictionary `d`, in the directory named by `basedir`.
+        If `bytes` is true, then treat bytestrings as bytes, else as text.
     """
     for name, contents in d.items():
         child = os.path.join(basedir, name)
         if isinstance(contents, string_types):
             mode = 'w'
-            if isinstance(contents, bytes_types):
+            if bytes and isinstance(contents, bytes_types):
                 mode += "b"
             f = open(child, mode)
             contents = reindentBlock(contents)
@@ -42,22 +44,3 @@ def removeFiles(d, basedir='.'):
             removeFiles(contents, child)
             if not os.listdir(child):
                 os.rmdir(child)
-
-if __name__ == '__main__':      #pragma: no cover
-    # Try it a little.
-    d = {
-        'test_makefiles': {
-            'hey.txt': """\
-                        This is hey.txt.
-                        It's very simple.
-                        """,
-            'subdir': {
-                'fooey': """\
-                            # Fooey
-                                Kablooey
-                            Ew.
-                            """
-            }
-        }
-    }
-    makeFiles(d)
